@@ -10,7 +10,7 @@ from flarchitect.utils.core_utils import convert_case
 def test_nested_schema_refs_follow_case(case: str) -> None:
     app = create_app_models({"API_SCHEMA_CASE": case})
     client = app.test_client()
-    spec = client.get("/apispec.json").json
+    spec = client.get("/docs/apispec.json").json
     spec_str = json.dumps(spec)
     expected = convert_case("Category", case)
     unexpected = "Category" if expected == "category" else "category"
